"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var WebviewUtilsWKNavigationDelegateImpl = (function (_super) {
    __extends(WebviewUtilsWKNavigationDelegateImpl, _super);
    function WebviewUtilsWKNavigationDelegateImpl() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebviewUtilsWKNavigationDelegateImpl.initWithOwnerAndHeaders = function (owner, headers) {
        var handler = WebviewUtilsWKNavigationDelegateImpl.new();
        handler._owner = owner;
        handler.headers = headers;
        return handler;
    };
    WebviewUtilsWKNavigationDelegateImpl.prototype.webViewDecidePolicyForNavigationActionDecisionHandler = function (webView, navigationAction, decisionHandler) {
        if (!navigationAction.request.URL) {
            return;
        }
        var isHttpRequest = navigationAction.request.URL.absoluteString.indexOf("http") === 0;
        var areHeadersAdded = true;
        this.headers.forEach(function (val, key) {
            areHeadersAdded = areHeadersAdded && navigationAction.request.valueForHTTPHeaderField(key) === val;
        });
        if (isHttpRequest && !areHeadersAdded) {
            decisionHandler(0);
            var customRequest_1 = new NSMutableURLRequest({
                URL: navigationAction.request.URL,
                cachePolicy: 0,
                timeoutInterval: 60
            });
            this.headers.forEach(function (val, key) {
                if (key.toLowerCase() === "user-agent") {
                    webView.customUserAgent = val;
                }
                else {
                    customRequest_1.setValueForHTTPHeaderField(val, key);
                }
            });
            webView.loadRequest(customRequest_1);
        }
        else {
            decisionHandler(1);
        }
    };
    WebviewUtilsWKNavigationDelegateImpl.ObjCProtocols = [WKNavigationDelegate];
    return WebviewUtilsWKNavigationDelegateImpl;
}(NSObject));
var WebViewUtils = (function (_super) {
    __extends(WebViewUtils, _super);
    function WebViewUtils() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebViewUtils.setUserAgent = function (wv, userAgent) {
        if (WebViewUtils.isWKWebView(wv)) {
            var headers = new Map();
            headers.set("User-Agent", userAgent);
            wv.ios.navigationDelegate = wv._delegate = WebviewUtilsWKNavigationDelegateImpl.initWithOwnerAndHeaders(new WeakRef(wv), headers);
        }
        else {
            NSUserDefaults.standardUserDefaults.registerDefaults(NSDictionary.dictionaryWithObjectForKey(userAgent, "UserAgent"));
        }
    };
    WebViewUtils.addHeaders = function (wv, headers) {
        if (WebViewUtils.isWKWebView(wv)) {
            wv.ios.navigationDelegate = wv._delegate = WebviewUtilsWKNavigationDelegateImpl.initWithOwnerAndHeaders(new WeakRef(wv), headers);
        }
        else {
            wv._delegate = WebViewUtils.initWithOwner(new WeakRef(wv));
            WebViewUtils.headers = headers;
        }
    };
    WebViewUtils.isWKWebView = function (wv) {
        return wv.ios.isKindOfClass(WKWebView.class());
    };
    WebViewUtils.initWithOwner = function (owner) {
        var delegate = new WebViewUtils();
        delegate._owner = owner;
        delegate._originalDelegate = owner.get()._delegate;
        return delegate;
    };
    WebViewUtils.prototype.webViewShouldStartLoadWithRequestNavigationType = function (webView, request, navigationType) {
        var urlString = request.URL.absoluteString;
        var isNavigationTypeBackForward = navigationType === 2;
        var isHttpRequest = urlString.indexOf("http") === 0;
        var areHeadersAdded = true;
        WebViewUtils.headers.forEach(function (val, key) {
            areHeadersAdded = areHeadersAdded && request.valueForHTTPHeaderField(key) === val;
        });
        if (!isHttpRequest || isNavigationTypeBackForward || areHeadersAdded || urlString === "about:blank") {
            return this._originalDelegate.webViewShouldStartLoadWithRequestNavigationType(webView, request, navigationType);
        }
        var nsMutableURLRequest = new NSMutableURLRequest({
            URL: request.URL,
            cachePolicy: 0,
            timeoutInterval: 60
        });
        WebViewUtils.headers.forEach(function (val, key) {
            nsMutableURLRequest.setValueForHTTPHeaderField(val, key);
        });
        webView.loadRequest(nsMutableURLRequest);
        return false;
    };
    WebViewUtils.prototype.webViewDidStartLoad = function (webView) {
        this._originalDelegate.webViewDidStartLoad(webView);
    };
    WebViewUtils.prototype.webViewDidFinishLoad = function (webView) {
        this._originalDelegate.webViewDidFinishLoad(webView);
    };
    WebViewUtils.prototype.webViewDidFailLoadWithError = function (webView, error) {
        this._originalDelegate.webViewDidFailLoadWithError(webView, error);
    };
    WebViewUtils.ObjCProtocols = [UIWebViewDelegate];
    return WebViewUtils;
}(NSObject));
exports.WebViewUtils = WebViewUtils;
